@@ -1,5 +1,5 @@
 package Yancy::Plugin::Auth::OAuth2;
-our $VERSION = '1.050';
+our $VERSION = '1.051';
 # ABSTRACT: Authenticate using an OAuth2 provider
 
 #pod =head1 SYNOPSIS
@@ -51,6 +51,11 @@ our $VERSION = '1.050';
 #pod
 #pod The URL to get an access token. The second step of the auth process.
 #pod
+#pod =head2 login_label
+#pod
+#pod The label for the button to log in using this OAuth2 provider. Defaults
+#pod to C<Login>.
+#pod
 #pod =head2 Sessions
 #pod
 #pod This module uses L<Mojolicious
@@ -82,8 +87,16 @@ our $VERSION = '1.050';
 #pod Validate there is a logged-in user and optionally that the user data has
 #pod certain values. See L<Yancy::Plugin::Auth::Role::RequireUser/require_user>.
 #pod
+#pod =head2 yancy.auth.login_form
+#pod
+#pod Returns the rendered login button.
+#pod
 #pod =head1 TEMPLATES
 #pod
+#pod =head2 yancy/auth/oauth2/login_form.html.ep
+#pod
+#pod Display the button to log in using this OAuth2 provider.
+#pod
 #pod =head2 layouts/yancy/auth.html.ep
 #pod
 #pod The layout that Yancy uses when displaying the login form, the
@@ -109,6 +122,7 @@ has client_id =>;
 has client_secret =>;
 has authorize_url =>;
 has token_url =>;
+has login_label => 'Login';
 
 sub register {
     my ( $self, $app, $config ) = @_;
@@ -119,11 +133,14 @@ sub register {
     $app->helper(
         'yancy.auth.logout' => currym( $self, 'logout' ),
     );
+    $app->helper(
+        'yancy.auth.login_form' => currym( $self, 'login_form' ),
+    );
 }
 
 sub init {
     my ( $self, $app, $config ) = @_;
-    for my $attr ( qw( moniker ua client_id client_secret ) ) {
+    for my $attr ( qw( moniker ua client_id client_secret login_label ) ) {
         next if !$config->{ $attr };
         $self->$attr( $config->{ $attr } );
     }
@@ -163,6 +180,21 @@ sub logout {
     return;
 }
 
+#pod =method login_form
+#pod
+#pod Get a link to log in using this OAuth2 provider.
+#pod
+#pod =cut
+
+sub login_form {
+    my ( $self, $c ) = @_;
+    return $c->render_to_string(
+        'yancy/auth/oauth2/login_form',
+        label => $self->login_label,
+        url => $self->route->render,
+    );
+}
+
 sub _handle_auth {
     my ( $self, $c ) = @_;
 
@@ -248,7 +280,7 @@ Yancy::Plugin::Auth::OAuth2 - Authenticate using an OAuth2 provider
 
 =head1 VERSION
 
-version 1.050
+version 1.051
 
 =head1 SYNOPSIS
 
@@ -289,6 +321,10 @@ Returns the access token of the currently-logged-in user.
 
 Clear any currently-logged-in user.
 
+=head2 login_form
+
+Get a link to log in using this OAuth2 provider.
+
 =head2 get_authorize_url
 
     my $url = $self->get_authorize_url( $c );
@@ -324,6 +360,11 @@ The URL to start the OAuth2 authorization process.
 
 The URL to get an access token. The second step of the auth process.
 
+=head2 login_label
+
+The label for the button to log in using this OAuth2 provider. Defaults
+to C<Login>.
+
 =head2 Sessions
 
 This module uses L<Mojolicious
@@ -355,8 +396,16 @@ user was found in the session.
 Validate there is a logged-in user and optionally that the user data has
 certain values. See L<Yancy::Plugin::Auth::Role::RequireUser/require_user>.
 
+=head2 yancy.auth.login_form
+
+Returns the rendered login button.
+
 =head1 TEMPLATES
 
+=head2 yancy/auth/oauth2/login_form.html.ep
+
+Display the button to log in using this OAuth2 provider.
+
 =head2 layouts/yancy/auth.html.ep
 
 The layout that Yancy uses when displaying the login form, the
